# -*- coding: utf-8 -*-

import functools
import warnings


# TODO: use PendingDeprecationWarning. (require executing test suite like standard Django warnings)
# https://docs.python.org/3/library/warnings.html
class RemovedInThxVersion040Warning(Warning):  # DeprecationWarning
    version = '0.4.0'


RemovedInNextThxVersionWarning = RemovedInThxVersion040Warning


def deprecated(version: str, deprecation_warning_class=None, help_message: str = None):
    """
    This is a decorator which can be used to mark functions
    as deprecated. It will result in a warning being emitted
    when the function is used.

    :param version: version from which deprecation started
    :param deprecation_warning_class: a different deprecation class to change warning
    :param help_message: additional message to show in warning

    """
    category = deprecation_warning_class or DeprecationWarning

    def decorator(func):
        """This is a decorator which can be used to mark functions
        as deprecated. It will result in a warning being emitted
        when the function is used."""
        @functools.wraps(func)
        def new_func(*args, **kwargs):
            warnings.simplefilter('always', category)  # turn off filter
            warnings.warn(
                f"\nCall function {func.__name__}, is deprecated from version {version} of thx-api package. "
                f"{help_message if help_message else ''}",
                category=category, stacklevel=2
            )
            warnings.simplefilter('default', category)  # reset filter
            return func(*args, **kwargs)
        return new_func
    return decorator
